@@ -1,6 +1,6 @@
 %% Copyright (c) 2010 Thomas Grenfell Smith
-%% Copyright (c) 2011, 2013-2015 Michael Walter
-%% Copyright (c) 2015-2016 Colin B. Macdonald
+%% Copyright (c) 2011, 2013-2016 Michael Walter
+%% Copyright (c) 2015-2017 Colin B. Macdonald
 %%
 %% Redistribution and use in source and binary forms, with or without
 %% modification, are permitted provided that the following conditions are met:
@@ -30,12 +30,10 @@
 
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
-%% @deftypefn  {Function File} {} doctest @var{target}
-%% @deftypefnx {Function File} {} doctest @var{target} -recursive
-%% @deftypefnx {Function File} {} doctest @var{target} -DIRECTIVE
-%% @deftypefnx {Function File} {} doctest @var{target} +DIRECTIVE
-%% @deftypefnx {Function File} {@var{success} =} doctest (@var{target}, @dots{})
-%% @deftypefnx {Function File} {[@var{numpass}, @var{numtests}, @var{summary]} =} doctest (@dots{})
+%% @deftypefn  {} {} doctest @var{target}
+%% @deftypefnx {} {} doctest @var{target} -nonrecursive
+%% @deftypefnx {} {@var{success} =} doctest (@var{target}, @dots{})
+%% @deftypefnx {} {[@var{numpass}, @var{numtests}, @var{summary}] =} doctest (@dots{})
 %% Run examples embedded in documentation.
 %%
 %% Doctest finds and runs code found in @var{target}, which can be a:
@@ -43,8 +41,7 @@
 %% @item function;
 %% @item class;
 %% @item Texinfo file;
-%% @item directory/folder (pass @code{-recursive} to descend
-%%       into subfolders);
+%% @item directory/folder (pass @code{-nonrecursive} to skip subfolders);
 %% @item cell array of such items.
 %% @end itemize
 %% When called with a single return value, return whether all tests have
@@ -171,8 +168,8 @@
 %% @end example
 %%
 %% Doctest provides the default flags @code{DOCTEST_OCTAVE} and
-%% @code{DOCTEST_MATLAB}, but you can access arbitrary variables and
-%% (nullary) functions.
+%% @code{DOCTEST_MATLAB}, but you can call functions and access arbitrary
+%% variables (including those defined by previous tests).
 %%
 %%
 %% By default, all adjacent white space is collapsed into a single space
@@ -194,29 +191,35 @@
 %%
 %% To disable the @code{...} wildcard, use the @code{-ELLIPSIS} directive.
 %%
-%% The default directives can be overridden on the command line using, for
-%% example, @code{doctest target -NORMALIZE_WHITESPACE +ELLIPSIS}.  Note that
-%% directives local to a test still take precident over these.
-%%
-%%
 %% @strong{Diary Style}
 %% When the m-file contains plaintext documentation, doctest finds tests
 %% by searching for lines that begin with @code{>>}.  It then finds the
 %% expected output by searching for the next @code{>>} or two blank lines.
 %%
 %% @strong{Octave/Texinfo Style}
-%% If your m-file contains Texinfo markup, then doctest finds code inside
-%% @code{@@example @dots{} @@end example} blocks.  Some comments:
+%% If your m-file contains Texinfo markup, then doctest finds code in
+%% @code{@@example @dots{} @@end example} blocks.  Note:
 %% @itemize
 %% @item The two-blank-lines convention is not required.
-%% @item The use of @code{>>} is not required as Octave documentation
-%%       conventionally indicates output with @code{@@print} and
-%%       @code{@@result}.  Ambiguities are resolving by assuming output
+%% @item The use of @code{>>} is neither required nor recommended as Octave
+%%       documentation conventionally indicates output with @code{@@result@{@}}
+%%       and @code{@@print@{@}}.  Ambiguities are resolving by assuming output
 %%       is indented further than input.
-%% @item You are free to use diary-style doctests inside
-%%       @code{@@example} blocks.
 %% @end itemize
 %%
+%% A typical Texinfo-style doctest looks like:
+%% @example
+%% a = 5;
+%% b = a + 1
+%%   @result{} b = 6
+%% disp("hello\nthere")
+%%   @print{} hello
+%%   @print{} there
+%% @end example
+%%
+%% The two styles are not mutually exclusive: this documentation is written
+%% in Texinfo using a hybrid approach.
+%%
 %% @seealso{test}
 %% @end deftypefn
 
@@ -238,7 +241,7 @@ if ~iscell(what)
 end
 
 % input parsing for options and directives
-recursive = false;
+recursive = true;
 directives = doctest_default_directives();
 for i = 1:(nargin-1)
   assert(ischar(varargin{i}))
@@ -246,10 +249,18 @@ for i = 1:(nargin-1)
   directive = varargin{i}(2:end);
   switch directive
     case 'recursive'
+      % weakly deprecated, not mentioned in help text
       assert(strcmp(pm, '-'))
       recursive = true;
+    case 'nonrecursive'
+      assert(strcmp(pm, '-'))
+      recursive = false;
     otherwise
       assert(strcmp(pm, '+') || strcmp(pm, '-'))
+      warning('Doctest:deprecated', ...
+              ['Support for specifying directives on the command line is deprecated\n' ...
+               '         and will be removed in a future version (for discussion, see\n' ...
+               '         https://github.com/catch22/octave-doctest/issues/127).']);
       enable = strcmp(varargin{i}(1), '+');
       directives = doctest_default_directives(directives, directive, enable);
   end
@@ -262,7 +273,7 @@ fid = 1;
 [color_ok, color_err, color_warn, reset] = doctest_colors(fid);
 
 % print banner
-fprintf(fid, 'Doctest v0.4.1: this is Free Software without warranty, see source.\n\n');
+fprintf(fid, 'Doctest v0.6.1: this is Free Software without warranty, see source.\n\n');
 
 
 summary = struct();
@@ -275,7 +286,7 @@ summary.num_tests_passed = 0;
 
 
 for i=1:numel(what)
-  summary = doctest_collect(what{i}, directives, summary, recursive, fid);
+  summary = doctest_collect(what{i}, directives, summary, recursive, 0, fid);
 end
 
 
